@@ -145,6 +145,33 @@ class BinaryBuilder:
 
         logger.info("Build artifacts cleaned")
 
+    def create_entry_script(self) -> Path:
+        """Create a wrapper script for the CLI entry point."""
+        entry_script = self.project_root / "riveter_entry.py"
+
+        entry_content = '''#!/usr/bin/env python3
+"""Entry point wrapper for Riveter CLI."""
+
+import sys
+from pathlib import Path
+
+# Add src directory to path
+project_root = Path(__file__).parent
+src_dir = project_root / "src"
+sys.path.insert(0, str(src_dir))
+
+# Import and run main
+from riveter.cli import main
+
+if __name__ == "__main__":
+    main()
+'''
+
+        with open(entry_script, "w") as f:
+            f.write(entry_content)
+
+        return entry_script
+
     def get_hidden_imports(self) -> List[str]:
         """Get list of hidden imports for PyInstaller.
 
@@ -239,8 +266,11 @@ class BinaryBuilder:
 
         spec_path = self.project_root / f"riveter-{target_platform}.spec"
 
+        # Create entry point wrapper script
+        entry_script = self.create_entry_script()
+
         spec_content = generate_spec(
-            entry_point=str(self.src_dir / "riveter" / "cli.py"),
+            entry_point=str(entry_script),
             hidden_imports=self.get_hidden_imports(),
             data_files=self.get_data_files(),
             target_platform=target_platform,
@@ -300,6 +330,12 @@ class BinaryBuilder:
 
         logger.info("Binary build completed successfully")
 
+        # Clean up entry script
+        entry_script = self.project_root / "riveter_entry.py"
+        if entry_script.exists():
+            entry_script.unlink()
+            logger.debug("Cleaned up entry script")
+
     def calculate_sha256(self, file_path: Path) -> str:
         """Calculate SHA256 checksum of a file.
 
