@@ -563,7 +563,27 @@ git checkout HEAD~1 -- pyproject.toml
 # Or manually edit pyproject.toml to restore previous version
 ```
 
-### 3. Revert Changelog Changes
+### 3. Revert CLI Version Changes
+```bash
+# Reset CLI module to previous state
+git checkout HEAD~1 -- src/riveter/cli.py
+
+# Or use version sync script rollback
+python scripts/sync_versions.py --rollback
+```
+
+### 4. Revert Homebrew Formula Changes
+```bash
+# If formula is in separate repository
+cd ../homebrew-riveter
+git checkout HEAD~1 -- Formula/riveter.rb
+
+# Or use version sync script
+cd ../riveter
+python scripts/sync_versions.py --rollback
+```
+
+### 5. Revert Changelog Changes
 ```bash
 # Reset CHANGELOG.md to previous state
 git checkout HEAD~1 -- CHANGELOG.md
@@ -571,16 +591,19 @@ git checkout HEAD~1 -- CHANGELOG.md
 # Or manually restore the [Unreleased] section
 ```
 
-### 4. Clean Up Build Artifacts
+### 6. Clean Up Build Artifacts
 ```bash
 # Remove build artifacts
 rm -rf dist/ build/ *.egg-info/
 
 # Clean up any temporary files
 git clean -fd
+
+# Remove version sync backups
+rm -rf .version_sync_backup/
 ```
 
-### 5. PyPI Cleanup (if package was published)
+### 7. PyPI Cleanup (if package was published)
 ⚠️ **Note**: PyPI does not allow deleting published packages. If the package was
 successfully published to PyPI, you cannot remove it. Instead:
 
@@ -588,23 +611,99 @@ successfully published to PyPI, you cannot remove it. Instead:
 - Mark the problematic version as yanked (if critical issues exist)
 - Update documentation to note the issue
 
-### 6. GitHub Release Cleanup (if created)
 ```bash
-# Delete the GitHub release via API or web interface
-# The release can be deleted from:
+# To yank a problematic version (if necessary)
+twine upload --repository pypi --skip-existing dist/*
+# Then contact PyPI support if yanking is needed
+```
+
+### 8. GitHub Release Cleanup (if created)
+```bash
+# Delete the GitHub release via API
+gh release delete {tag} --yes
+
+# Or delete via web interface:
 # https://github.com/{os.getenv('GITHUB_REPOSITORY', 'owner/repo')}/releases
 ```
 
-### 7. Verify Rollback
+### 9. Homebrew Tap Cleanup (if updated)
+```bash
+# If Homebrew formula was updated, revert it
+cd ../homebrew-riveter
+git reset --hard HEAD~1
+git push --force-with-lease origin main
+
+# Or manually edit Formula/riveter.rb to restore previous version
+```
+
+### 10. Verify Rollback
 ```bash
 # Check current version
 grep version pyproject.toml
 
+# Check CLI version consistency
+python -c "import tomllib; print(tomllib.load(open('pyproject.toml', 'rb'))['project']['version'])"
+
 # Check git tags
 git tag -l | grep {version}
 
 # Check git status
 git status
+
+# Validate version consistency
+python scripts/sync_versions.py --validate
+```
+
+## Automated Rollback
+
+Use the automated rollback script for faster recovery:
+
+```bash
+# Automated version synchronization rollback
+python scripts/sync_versions.py --rollback
+
+# Automated Homebrew error recovery
+python scripts/homebrew_error_recovery.py --recover
+
+# Comprehensive workflow error recovery
+python scripts/workflow_error_handler.py --create-rollback-doc {version} --tag {tag}
+```
+
+## Specific Error Recovery
+
+### Version Synchronization Failures
+```bash
+# Check version consistency
+python scripts/sync_versions.py --validate --debug
+
+# Manual version sync
+python scripts/sync_versions.py --sync
+
+# Rollback version changes
+python scripts/sync_versions.py --rollback
+```
+
+### Homebrew Installation Failures
+```bash
+# Diagnose Homebrew errors
+python scripts/homebrew_error_recovery.py --diagnose error.log --recover
+
+# Manual Homebrew cleanup
+brew untap scottryanhoward/homebrew-riveter
+brew cleanup --prune=all
+brew tap scottryanhoward/homebrew-riveter
+```
+
+### PyPI Publication Failures
+```bash
+# Check PyPI token
+echo $PYPI_API_TOKEN | cut -c1-10
+
+# Validate package before upload
+twine check dist/*
+
+# Test upload to TestPyPI first
+twine upload --repository testpypi dist/*
 ```
 
 ## Prevention for Next Release
@@ -613,16 +712,76 @@ git status
 2. **Check all validations**: Ensure all pre-release checks pass
 3. **Review changes**: Manually review version and changelog updates
 4. **Test locally**: Build and test packages locally before release
+5. **Validate version sync**: Run `python scripts/sync_versions.py --validate`
+6. **Test Homebrew formula**: Run `brew audit --strict riveter`
+7. **Check network connectivity**: Ensure stable internet connection
+8. **Verify secrets**: Ensure all required tokens are valid and have correct permissions
+
+## Troubleshooting Common Issues
+
+### Issue: Version Mismatch
+**Symptoms**: Binary version doesn't match formula version
+**Solution**:
+```bash
+python scripts/sync_versions.py --sync
+python scripts/sync_versions.py --validate
+```
+
+### Issue: Homebrew Tap Installation Fails
+**Symptoms**: `brew tap` command fails with exit code 1
+**Solution**:
+```bash
+brew untap scottryanhoward/homebrew-riveter
+brew update
+brew tap scottryanhoward/homebrew-riveter
+```
+
+### Issue: Formula Audit Fails
+**Symptoms**: `brew audit` command fails
+**Solution**:
+```bash
+# Check formula syntax
+ruby -c Formula/riveter.rb
+
+# Validate URLs and checksums
+python scripts/sync_versions.py --update-formula
+```
+
+### Issue: PyPI Upload Fails
+**Symptoms**: `twine upload` fails with authentication error
+**Solution**:
+```bash
+# Check token format
+echo $PYPI_API_TOKEN | grep "^pypi-"
+
+# Test with TestPyPI first
+twine upload --repository testpypi dist/*
+```
 
 ## Emergency Contacts
 
 - Repository maintainers: Check CODEOWNERS file
 - GitHub repository: https://github.com/{os.getenv('GITHUB_REPOSITORY', 'owner/repo')}
 - Issues: https://github.com/{os.getenv('GITHUB_REPOSITORY', 'owner/repo')}/issues
+- Homebrew tap: https://github.com/ScottRyanHoward/homebrew-riveter
+
+## Recovery Verification Checklist
+
+- [ ] Git tag removed (local and remote)
+- [ ] pyproject.toml version reverted
+- [ ] CLI version reverted
+- [ ] Homebrew formula reverted (if applicable)
+- [ ] Changelog reverted
+- [ ] Build artifacts cleaned up
+- [ ] Version consistency validated
+- [ ] Git status clean
+- [ ] No uncommitted changes
+- [ ] All tests passing
 
 ---
 Generated on: {time.strftime('%Y-%m-%d %H:%M:%S UTC')}
 Workflow run: {os.getenv('GITHUB_RUN_ID', 'unknown')}
+Recovery tools: sync_versions.py, homebrew_error_recovery.py, workflow_error_handler.py
 """
         return rollback_doc
 
