@@ -29,6 +29,11 @@ import click
 from rich.console import Console
 from rich.table import Table
 
+try:
+    from importlib.metadata import version as get_version
+except ImportError:
+    from importlib_metadata import version as get_version
+
 from .config import ConfigManager, get_environment_from_context
 from .extract_config import extract_terraform_config
 from .logging import LogFormat, LogLevel, configure_logging
@@ -46,7 +51,7 @@ console = Console()
 
 
 @click.group()
-@click.version_option(version="0.1.0")
+@click.version_option(version=get_version("riveter"))
 def main() -> None:
     """Riveter - Infrastructure Rule Enforcement as Code.
 
